@@ -22,7 +22,6 @@
 #include "contactgroupeditor.h"
 #include "contactgroupeditor_p.h"
 
-#include "autoqpointer_p.h"
 #include "contactgroupmodel_p.h"
 #include "contactgroupeditordelegate_p.h"
 #include "waitingoverlay_p.h"
@@ -47,9 +46,6 @@ using namespace Akonadi;
 
 ContactGroupEditor::Private::Private(ContactGroupEditor *parent)
     : mParent(parent)
-    , mMonitor(nullptr)
-    , mReadOnly(false)
-    , mGroupModel(nullptr)
 {
 }
 
@@ -88,15 +84,18 @@ void ContactGroupEditor::Private::itemFetchDone(KJob *job)
 
         Akonadi::CollectionFetchJob *collectionFetchJob = new Akonadi::CollectionFetchJob(mItem.parentCollection(),
                                                                                           Akonadi::CollectionFetchJob::Base);
-        mParent->connect(collectionFetchJob, SIGNAL(result(KJob *)),
-                         SLOT(parentCollectionFetchDone(KJob *)));
+        mParent->connect(collectionFetchJob, &CollectionFetchJob::result, mParent, [this](KJob *job) {
+            parentCollectionFetchDone(job);
+        });
     } else {
         const KContacts::ContactGroup group = mItem.payload<KContacts::ContactGroup>();
         loadContactGroup(group);
 
         setReadOnly(mReadOnly);
 
-        QTimer::singleShot(0, mParent, SLOT(adaptHeaderSizes()));
+        QTimer::singleShot(0, mParent, [this]() {
+            adaptHeaderSizes();
+        });
     }
 }
 
@@ -121,7 +120,9 @@ void ContactGroupEditor::Private::parentCollectionFetchDone(KJob *job)
 
     setReadOnly(mReadOnly);
 
-    QTimer::singleShot(0, mParent, SLOT(adaptHeaderSizes()));
+    QTimer::singleShot(0, mParent, [this]() {
+        adaptHeaderSizes();
+    });
 }
 
 void ContactGroupEditor::Private::storeDone(KJob *job)
@@ -141,7 +142,7 @@ void ContactGroupEditor::Private::storeDone(KJob *job)
 void ContactGroupEditor::Private::itemChanged(const Item &item, const QSet<QByteArray> &)
 {
     Q_UNUSED(item)
-    AutoQPointer<QMessageBox> dlg = new QMessageBox(mParent);   //krazy:exclude=qclasses
+    QPointer<QMessageBox> dlg = new QMessageBox(mParent);   //krazy:exclude=qclasses
 
     dlg->setInformativeText(i18n("The contact group has been changed by someone else.\nWhat should be done?"));
     dlg->addButton(i18n("Take over changes"), QMessageBox::AcceptRole);
@@ -152,9 +153,12 @@ void ContactGroupEditor::Private::itemChanged(const Item &item, const QSet<QByte
         job->fetchScope().fetchFullPayload();
         job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
 
-        mParent->connect(job, SIGNAL(result(KJob *)), mParent, SLOT(itemFetchDone(KJob *)));
+        mParent->connect(job, &ItemFetchJob::result, mParent, [this](KJob *job) {
+            itemFetchDone(job);
+        });
         new WaitingOverlay(job, mParent);
     }
+    delete dlg;
 }
 
 void ContactGroupEditor::Private::loadContactGroup(const KContacts::ContactGroup &group)
@@ -194,10 +198,13 @@ void ContactGroupEditor::Private::setupMonitor()
 {
     delete mMonitor;
     mMonitor = new Monitor;
+    mMonitor->setObjectName(QStringLiteral("ContactGroupEditorMonitor"));
     mMonitor->ignoreSession(Session::defaultSession());
 
-    connect(mMonitor, SIGNAL(itemChanged(Akonadi::Item,QSet<QByteArray>)),
-            mParent, SLOT(itemChanged(Akonadi::Item,QSet<QByteArray>)));
+    connect(mMonitor, &Monitor::itemChanged,
+            mParent, [this](const Akonadi::Item &item, const QSet<QByteArray> &arrays) {
+        itemChanged(item, arrays);
+    });
 }
 
 void ContactGroupEditor::Private::setReadOnly(bool readOnly)
@@ -223,8 +230,10 @@ ContactGroupEditor::ContactGroupEditor(Mode mode, QWidget *parent)
         KContacts::ContactGroup dummyGroup;
         d->mGroupModel->loadContactGroup(dummyGroup);
 
-        QTimer::singleShot(0, this, SLOT(adaptHeaderSizes()));
-        QTimer::singleShot(0, d->mGui.groupName, SLOT(setFocus()));
+        QTimer::singleShot(0, this, [this]() {
+            d->adaptHeaderSizes();
+        });
+        QTimer::singleShot(0, d->mGui.groupName, QOverload<>::of(&ContactGroupEditor::setFocus));
     }
 
     d->mGui.membersView->header()->setStretchLastSection(true);
@@ -245,7 +254,9 @@ void ContactGroupEditor::loadContactGroup(const Akonadi::Item &item)
     job->fetchScope().fetchFullPayload();
     job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
 
-    connect(job, SIGNAL(result(KJob *)), SLOT(itemFetchDone(KJob *)));
+    connect(job, &ItemModifyJob::result, this, [this](KJob *job) {
+        d->itemFetchDone(job);
+    });
 
     d->setupMonitor();
     d->mMonitor->setItemMonitored(item);
@@ -273,20 +284,24 @@ bool ContactGroupEditor::saveContactGroup()
         d->mItem.setPayload<KContacts::ContactGroup>(group);
 
         ItemModifyJob *job = new ItemModifyJob(d->mItem);
-        connect(job, SIGNAL(result(KJob *)), SLOT(storeDone(KJob *)));
+        connect(job, &ItemModifyJob::result, this, [this](KJob *job) {
+            d->storeDone(job);
+        });
     } else if (d->mMode == CreateMode) {
         if (!d->mDefaultCollection.isValid()) {
             const QStringList mimeTypeFilter(KContacts::ContactGroup::mimeType());
 
-            AutoQPointer<CollectionDialog> dlg = new CollectionDialog(this);
+            QPointer<CollectionDialog> dlg = new CollectionDialog(this);
             dlg->setMimeTypeFilter(mimeTypeFilter);
             dlg->setAccessRightsFilter(Collection::CanCreateItem);
-            dlg->setWindowTitle(i18n("Select Address Book"));
+            dlg->setWindowTitle(i18nc("@title:window", "Select Address Book"));
             dlg->setDescription(i18n("Select the address book the new contact group shall be saved in:"));
 
             if (dlg->exec() == QDialog::Accepted) {
                 setDefaultAddressBook(dlg->selectedCollection());
+                delete dlg;
             } else {
+                delete dlg;
                 return false;
             }
         }
@@ -301,7 +316,9 @@ bool ContactGroupEditor::saveContactGroup()
         item.setMimeType(KContacts::ContactGroup::mimeType());
 
         ItemCreateJob *job = new ItemCreateJob(item, d->mDefaultCollection);
-        connect(job, SIGNAL(result(KJob *)), SLOT(storeDone(KJob *)));
+        connect(job, &ItemCreateJob::result, this, [this](KJob *job) {
+            d->storeDone(job);
+        });
     }
 
     return true;
