@@ -109,8 +109,9 @@ public:
     /**
      * Returns the ContactGroupEditor that is used by the dialog.
      */
-    ContactGroupEditor *editor() const;
+    Q_REQUIRED_RESULT ContactGroupEditor *editor() const;
 
+    void reject() override;
 Q_SIGNALS:
     /**
      * This signal is emitted whenever a contact group was updated or stored.
