@@ -32,10 +32,10 @@
 #include <itemfetchscope.h>
 #include <kcontacts/addressee.h>
 #include <kcontacts/contactgroup.h>
-#include <kcolorscheme.h>
+#include <KColorScheme>
 
 #include <KLocalizedString>
-#include <kstringhandler.h>
+#include <KStringHandler>
 
 #include <QVBoxLayout>
 #include <QIcon>
@@ -68,7 +68,7 @@ public:
 
     void updateView()
     {
-        mParent->setWindowTitle(i18n("Contact Group %1", mCurrentGroupName));
+        mParent->setWindowTitle(i18nc("@title:window", "Contact Group %1", mCurrentGroupName));
 
         KContacts::ContactGroup group;
         group.setName(mCurrentGroupName);
