@@ -28,7 +28,9 @@ int main(int argc, char **argv)
 
     Akonadi::EmailAddressSelectionDialog dlg;
     if (dlg.exec()) {
-        for (const Akonadi::EmailAddressSelection &selection : dlg.selectedAddresses()) {
+        const auto selectedAddress =  dlg.selectedAddresses();
+
+        for (const Akonadi::EmailAddressSelection &selection : selectedAddress) {
             qDebug("%s: %s", qPrintable(selection.name()), qPrintable(selection.email()));
         }
     }
