@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -34,7 +34,7 @@ PhoneTypeDialog::PhoneTypeDialog(KContacts::PhoneNumber::Type type, QWidget *par
     : QDialog(parent)
     , mType(type)
 {
-    setWindowTitle(i18n("Edit Phone Number"));
+    setWindowTitle(i18nc("@title:window", "Edit Phone Number"));
 
     QVBoxLayout *layout = new QVBoxLayout(this);
 
@@ -73,7 +73,7 @@ PhoneTypeDialog::PhoneTypeDialog(KContacts::PhoneNumber::Type type, QWidget *par
 
 KContacts::PhoneNumber::Type PhoneTypeDialog::type() const
 {
-    KContacts::PhoneNumber::Type type = nullptr;
+    KContacts::PhoneNumber::Type type = {};
 
     for (int i = 0; i < mGroup->buttons().count(); ++i) {
         QCheckBox *box = qobject_cast<QCheckBox *>(mGroup->buttons().at(i));
