@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -26,7 +26,7 @@ using namespace ContactEditor;
 ContactEditorComboBox::ContactEditorComboBox(QWidget *parent)
     : QComboBox(parent)
 {
-    setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
+    setSizeAdjustPolicy(QComboBox::AdjustToContents);
 }
 
 ContactEditorComboBox::~ContactEditorComboBox()
